@@ -3,4 +3,6 @@ optimizer = dict(type='Adadelta', lr=1.0)
 optimizer_config = dict(grad_clip=None)
 # learning policy
 lr_config = dict(policy='step', step=[])
-total_epochs = 5
+# running settings
+runner = dict(type='EpochBasedRunner', max_epochs=5)
+checkpoint_config = dict(interval=1)
