@@ -1,5 +1,5 @@
 _base_ = [
-    '../../_base_/runtime_10e.py',
+    '../../_base_/default_runtime.py',
     '../../_base_/det_models/ocr_mask_rcnn_r50_fpn_ohem.py',
     '../../_base_/schedules/schedule_sgd_160e.py',
     '../../_base_/det_datasets/icdar2017.py',
