@@ -12,8 +12,13 @@ test_list = {{_base_.test_list}}
 train_pipeline = {{_base_.train_pipeline}}
 test_pipeline = {{_base_.test_pipeline}}
 
+max_seq_len = 40
+
 label_convertor = dict(
-    type='AttnConvertor', dict_type='DICT90', with_unknown=True)
+    type='AttnConvertor',
+    dict_type='DICT90',
+    with_unknown=True,
+    max_seq_len=max_seq_len)
 
 model = dict(
     type='NRTR',
@@ -27,7 +32,7 @@ model = dict(
     decoder=dict(type='NRTRDecoder'),
     loss=dict(type='TFLoss'),
     label_convertor=label_convertor,
-    max_seq_len=40)
+    max_seq_len=max_seq_len)
 
 data = dict(
     samples_per_gpu=128,
