@@ -3,6 +3,7 @@ from mmdet.datasets.builder import DATASETS
 
 from mmocr.core.evaluation.ocr_metric import eval_ocr_metric
 from mmocr.datasets.base_dataset import BaseDataset
+from mmocr.utils import is_type_list
 
 
 @DATASETS.register_module()
@@ -23,6 +24,8 @@ class OCRDataset(BaseDataset):
         Returns:
             dict[str: float]
         """
+        assert isinstance(metric, str) or is_type_list(metric, str)
+
         gt_texts = []
         pred_texts = []
         for i in range(len(self)):
@@ -31,6 +34,6 @@ class OCRDataset(BaseDataset):
             gt_texts.append(text)
             pred_texts.append(results[i]['text'])
 
-        eval_results = eval_ocr_metric(pred_texts, gt_texts)
+        eval_results = eval_ocr_metric(pred_texts, gt_texts, metric=metric)
 
         return eval_results
