@@ -1,14 +1,12 @@
-import torch.nn as nn
+# Copyright (c) OpenMMLab. All rights reserved.
+from mmcv.runner import BaseModule
 
 from mmocr.models.builder import ENCODERS
 
 
 @ENCODERS.register_module()
-class BaseEncoder(nn.Module):
+class BaseEncoder(BaseModule):
     """Base Encoder class for text recognition."""
 
-    def init_weights(self):
-        pass
-
     def forward(self, feat, **kwargs):
         return feat
