@@ -841,15 +841,13 @@ class MMOCR:
         num_res = len(img_list)
         if args.output:
             output_path = Path(args.output)
-            if output_path.is_dir():
+            if output_path.is_dir() or not output_path.exists():
                 args.output = [
                     str(output_path / f'out_{x}.png') for x in args.filenames
                 ]
             else:
-                args.output = [str(args.output)]
-                if args.batch_mode:
-                    raise AssertionError('Output of multiple images inference'
-                                         ' must be a directory')
+                raise TypeError(
+                    f'output {output_path} cannot be an existing file!')
         else:
             args.output = [None] * num_res
 
